%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}
%{!?ruby_sitelib: %global ruby_sitelib %(/usr/bin/ruby -rrbconfig  -e 'puts Config::CONFIG["sitelibdir"] ')}
%{!?ruby_sitearch: %global ruby_sitearch %(/usr/bin/ruby -rrbconfig -e 'puts Config::CONFIG["sitearchdir"] ')}

# ===========

# LIBRARY VERSIONS
# Update these lib numbers in accordance with library numbering policy and best practices.
# http://www.gnu.org/software/libtool/manual/libtool.html#Versioning
#
# Fromat: current[:revision[:age]]
#
# current:  The most recent interface number that this library implements.
# revision: The implementation number of the current interface.
# age:      The difference between the newest and oldest interfaces that this library implements.
#           In other words, the library implements all the interface numbers in the range from
#           number current - age to current. 
#
#  1. Start with version information of ‘0:0:0’ for each libtool library.
#  2. Update the version information only immediately before a public release of your software.
#     More frequent updates are unnecessary, and only guarantee that the current interface number
#     gets larger faster.
#  3. If the library source code has changed at all since the last update, then increment revision
#     (‘c:r:a’ becomes ‘c:r+1:a’).
#  4. If any interfaces have been added, removed, or changed since the last update, increment current,
#     and set revision to 0.
#  5. If any interfaces have been added since the last public release, then increment age.
#  6. If any interfaces have been removed or changed since the last public release, then set age to 0. 
#  
# Update qpid/cpp/src/versions.cmake file to change library version (when using cmake)
#
# Note that qpidtypes and qpidmessaging are the libraries which contain
# our official public interfaces and we try not to change.
# The others have no guarantee, which is why we rev them with every release.
# ===========

Name:           qpid-cpp
Version:        0.30
Release:        11%{?dist}
Summary:        Libraries for Qpid C++ client applications
Group:          System Environment/Libraries
License:        ASL 2.0
URL:            http://qpid.apache.org
Source0:        qpid-cpp-%{version}.tar.gz
Source3:        qpidd.1.gz
Source4:        qpidd.sasldb
Patch0:         mrg.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires: cmake
BuildRequires: make
BuildRequires: gcc-c++
BuildRequires: boost-devel
BuildRequires: libtool
BuildRequires: doxygen
BuildRequires: pkgconfig
BuildRequires: ruby
BuildRequires: ruby-devel
BuildRequires: python
BuildRequires: python-devel
BuildRequires: swig
BuildRequires: cyrus-sasl-devel
BuildRequires: cyrus-sasl-lib
BuildRequires: cyrus-sasl
BuildRequires: boost-program-options
BuildRequires: boost-filesystem
BuildRequires: libuuid-devel
BuildRequires: libibverbs-devel
BuildRequires: librdmacm-devel
BuildRequires: nss-devel
BuildRequires: nspr-devel
BuildRequires: xqilla-devel
BuildRequires: xerces-c-devel
BuildRequires: db4-devel
BuildRequires: libaio-devel
BuildRequires: qpid-proton-c-devel >= 0.9

%description

Run-time libraries for AMQP client applications developed using Qpid
C++. Clients exchange messages with an AMQP message broker using
the AMQP protocol.

# === Package: qpid-cpp-client ===

%package client
Summary: Libraries for Qpid C++ client applications
Group: System Environment/Libraries
Requires: boost-filesystem
Requires: boost-program-options
Requires: boost-system
Requires:  qpid-proton-c >= 0.9
Obsoletes: qpidc
Obsoletes: %{name}-client-ssl

Requires(post):/sbin/chkconfig
Requires(preun):/sbin/chkconfig
Requires(preun):/sbin/service
Requires(postun):/sbin/service

%description client
Run-time libraries for AMQP client applications developed using Qpid
C++. Clients exchange messages with an AMQP message broker using
the AMQP protocol.

%files client
%defattr(-,root,root,-)
%doc LICENSE
%doc NOTICE
%doc README.txt
%doc INSTALL
%doc RELEASE_NOTES
%doc DESIGN
%_libdir/libqpidcommon.so.*
%_libdir/libqpidclient.so.*
%_libdir/libqpidmessaging.so.*
%_libdir/libqpidtypes.so.*
%dir %_libdir/qpid
%dir %_libdir/qpid/client
%dir %_sysconfdir/qpid
%dir %_libdir/qpid/daemon
%config(noreplace) %_sysconfdir/qpid/qpidc.conf

%post client
/sbin/ldconfig

%postun client
/sbin/ldconfig

# === Package: qpid-cpp-client-devel ===

%package client-devel
Summary: Header files, documentation and testing tools for developing Qpid C++ clients
Group: Development/System
Requires: %{name}-client = %{version}-%{release}
Requires: boost-devel
Requires: %_includedir/uuid/uuid.h
Requires: boost-filesystem
Requires: boost-program-options
Requires: python
Obsoletes: qpidc-devel
Obsoletes: qpidc-perftest

%description client-devel
Libraries, header files and documentation for developing AMQP clients
in C++ using Qpid.  Qpid implements the AMQP messaging specification.

%files client-devel
%defattr(-,root,root,-)
%dir %_includedir/qpid
%_includedir/qpid/*.h
%_includedir/qpid/qpid.i
%_includedir/qpid/swig_perl_typemaps.i
%{_includedir}/qpid/swig_python_typemaps.i
%{_includedir}/qpid/swig_ruby_typemaps.i
%_includedir/qpid/client
%_includedir/qpid/framing
%_includedir/qpid/sys
%_includedir/qpid/messaging
%_includedir/qpid/types
%_libdir/libqpidcommon.so
%_libdir/libqpidclient.so
%_libdir/libqpidmessaging.so
%_libdir/libqpidtypes.so
%_libdir/pkgconfig/qpid.pc
%_libdir/cmake/Qpid/QpidConfig.cmake
%_libdir/cmake/Qpid/QpidConfigVersion.cmake
%_datadir/qpid/examples/messaging
%defattr(755,root,root,-)
%_libexecdir/qpid/tests/qpid-perftest
%_libexecdir/qpid/tests/qpid-topic-listener
%_libexecdir/qpid/tests/qpid-topic-publisher
%_libexecdir/qpid/tests/qpid-latency-test
%_libexecdir/qpid/tests/qpid-client-test
%_libexecdir/qpid/tests/qpid-txtest
%_libexecdir/qpid/tests/qpid-ping
%_libexecdir/qpid/tests/qpid-txtest2
%_bindir/qpid-send
%_bindir/qpid-receive

%post client-devel
/sbin/ldconfig

%postun client-devel
/sbin/ldconfig

# === Package: qpid-cpp-client-devel-docs ===

%package client-devel-docs
Summary: AMQP client development documentation
Group: Documentation
BuildArch: noarch
Obsoletes: qpidc-devel-docs

%description client-devel-docs
This package includes the AMQP clients development documentation in HTML
format for easy browsing.

%files client-devel-docs
%defattr(-,root,root,-)
%{_docdir}/qpid-cpp-%{version}

# === Package: qpid-cpp-server ===

%package server
Summary: An AMQP message broker daemon
Group: System Environment/Daemons
Requires: %{name}-client = %{version}-%{release}
Requires: cyrus-sasl
Requires:  qpid-proton-c >= 0.9
Obsoletes: qpidd
Obsoletes: qpidd-acl
Obsoletes: %{name}-server-ssl

%description server
A message broker daemon that receives stores and routes messages using
the open AMQP messaging protocol.

%files server
%defattr(-,root,root,-)
%_libdir/libqpidbroker.so.*
%_sbindir/qpidd
%config(noreplace) %_sysconfdir/qpid/qpidd.conf
%config(noreplace) %_sysconfdir/sasl2/qpidd.conf
%{_initrddir}/qpidd
%dir %_libdir/qpid/daemon
%_libdir/qpid/daemon/amqp.so
%attr(755, qpidd, qpidd) %dir %_localstatedir/lib/qpidd
%attr(600, qpidd, qpidd) %config(noreplace) %_localstatedir/lib/qpidd/qpidd.sasldb
%attr(755, qpidd, qpidd) %dir %_localstatedir/run/qpidd
%doc %_mandir/man1/qpidd.*

%pre server
getent group qpidd >/dev/null || groupadd -r qpidd
getent passwd qpidd >/dev/null || \
  useradd -r -M -g qpidd -d %{_localstatedir}/lib/qpidd -s /sbin/nologin \
    -c "Owner of Qpidd Daemons" qpidd
exit 0

%post server
# This adds the proper /etc/rc*.d links for the script
/sbin/chkconfig --add qpidd
/sbin/ldconfig

%preun server
# Check that this is actual deinstallation, not just removing for upgrade.
if [ $1 = 0 ]; then
        /sbin/service qpidd stop >/dev/null 2>&1 || :
        /sbin/chkconfig --del qpidd
fi

%postun server
if [ "$1" -ge "1" ]; then
        /sbin/service qpidd condrestart >/dev/null 2>&1 || :
fi
/sbin/ldconfig

# === Package: qpid-cpp-server-devel ===

%package server-devel
Summary: Libraries and header files for developing Qpid broker extensions
Group: Development/System
Requires: %{name}-client-devel = %{version}-%{release}
Requires: %{name}-server = %{version}-%{release}
Requires: boost-devel
Requires: boost-filesystem
Requires: boost-program-options
Obsoletes: qpidd-devel

%description server-devel
Libraries and header files for developing extensions to the
Qpid broker daemon.

%files server-devel
%defattr(-,root,root,-)
%_libdir/libqpidbroker.so

%post server-devel
/sbin/ldconfig

%postun server-devel
/sbin/ldconfig

%package server-ha
Summary: Provides extensions to the AMQP message broker to provide high availability
Group: System Environment/Daemons

Requires: %{name}-server = %{version}-%{release}
Requires: %{name}-client = %{version}-%{release}
Obsoletes: %{name}-server-cluster

%description server-ha
%{summary}.

%files server-ha
%{_initrddir}/qpidd-primary
%{_libdir}/qpid/daemon/ha.so
%doc README-HA.txt

%post server-ha
/sbin/chkconfig --add qpidd-primary
/sbin/ldconfig

%preun server-ha
if [ $1 = 0 ]; then
  /sbin/service qpidd-primary stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del qpidd-primary
fi

%postun server-ha
if [ $1 -ge 1 ]; then
  /sbin/service qpidd-primary condrestart >/dev/null 2>&1 || :
fi
/sbin/ldconfig

# === Package: qpid-cpp-client-rdma ===

%package client-rdma
Summary: RDMA Protocol support (including Infiniband) for Qpid clients
Group: System Environment/Libraries
Requires: %{name}-client = %{version}-%{release}
Obsoletes: qpidc-rdma

%description client-rdma
A client plugin and support library to support RDMA protocols (including
Infiniband) as the transport for Qpid messaging.

%files client-rdma
%defattr(-,root,root,-)
%_libdir/librdmawrap.so.*
%_libdir/qpid/client/rdmaconnector.so
%config(noreplace) %_sysconfdir/qpid/qpidc.conf

%post client-rdma
/sbin/ldconfig

%postun client-rdma
/sbin/ldconfig

# === Package: qpid-cpp-server-rdma ===

%package server-rdma
Summary: RDMA Protocol support (including Infiniband) for the Qpid daemon
Group: System Environment/Libraries
Requires: %{name}-server = %{version}-%{release}
Requires: %{name}-client = %{version}-%{release}
Requires: %{name}-client-rdma = %{version}-%{release}
Obsoletes: qpidd-rdma

%description server-rdma
A Qpid daemon plugin to support RDMA protocols (including Infiniband) as the
transport for AMQP messaging.

%files server-rdma
%defattr(-,root,root,-)
%_libdir/qpid/daemon/rdma.so

%post server-rdma
/sbin/ldconfig

%postun server-rdma
/sbin/ldconfig

# === Package: qpid-cpp-server-xml ===

%package server-xml
Summary: XML extensions for the Qpid daemon
Group: System Environment/Libraries
Requires: %{name}-server = %{version}-%{release}
Requires: %{name}-client = %{version}-%{release}
Requires: xqilla
Requires: xerces-c
Obsoletes: qpidd-xml

%description server-xml
A Qpid daemon plugin to support extended XML-based routing of AMQP
messages.

%files server-xml
%defattr(-,root,root,-)
%_libdir/qpid/daemon/xml.so

%post server-xml
/sbin/ldconfig

%postun server-xml
/sbin/ldconfig

# === Package: qpid-cpp-server-linearstore ===

%package server-linearstore
Summary: Red Hat persistence extension to the Qpid messaging system
Group: System Environment/Libraries
License: LGPL 2.1+
Requires: %{name}-server = %{version}-%{release}
Requires: %{name}-client = %{version}-%{release}
Requires: db4
Requires: libaio
Obsoletes: rhm
Obsoletes: %{name}-server-store
Conflicts: %{name}-server-store

%description server-linearstore
Red Hat persistence extension to the Qpid AMQP broker: persistent message
storage using a libaio-based asynchronous journal.

%files server-linearstore
%defattr(-,root,root,-)
%{_libdir}/qpid/daemon/linearstore.so
%{_libdir}/liblinearstoreutils.so

%post server-linearstore
/sbin/ldconfig

%postun server-linearstore

# === Package: rh-qpid-cpp-tests (internal package, not distributed) ===

%package -n rh-%{name}-tests
Summary: Internal Red Hat test utilities
Group: System Environment/Tools
Requires: %{name}-server = %{version}-%{release}
Requires: %{name}-client = %{version}-%{release}
Obsoletes: rh-qpidc-tests

%description -n rh-%{name}-tests
Tools which can be used by Red Hat for doing different tests
in RHTS and other places and which customers do not need
to receive at all.

%files -n rh-%{name}-tests
%defattr(755,root,root,-)
%{_libexecdir}/qpid/tests/receiver
%{_libexecdir}/qpid/tests/sender

# ===

%prep

%setup -q -n qpid-cpp-%{version}

# Qpid patch
%patch0 -p3

# ===
%build

pushd %{_builddir}/qpid-cpp-%{version}
%cmake  -DBUILD_LEGACYSTORE=OFF -DBUILD_LINEARSTORE=ON -DCMAKE_BUILD_TYPE=RelWithDebInfo -DCMAKE_EXE_LINKER_FLAGS="-Wl,-z,relro,-z,now" -DCMAKE_SHARED_LINKER_FLAGS="-Wl,-z,relro" -DCMAKE_MODULE_LINKER_FLAGS="-Wl,-z,relro"
make %{?_smp_mflags}
make docs-user-api
popd

# ===

%install
rm -rf %{buildroot}

pushd %{_builddir}/qpid-cpp-%{version}
%make_install
popd

# Install perftest utilities
pushd %{_builddir}/qpid-cpp-%{version}/src/tests

rm -f %{buildroot}%{_libdir}/qpid/daemon/store.so*
rm -f %{buildroot}%_datadir/qpid/examples/README.txt
rm -fr %{buildroot}%_datadir/qpid/examples/qmf2
rm -fr %{buildroot}%python_sitearch/*qmf*
rm -f %{buildroot}%{python_sitearch}/_qpid_messaging*
rm -f %{buildroot}%{python_sitearch}/qpid_messaging*
rm -f %{buildroot}%ruby_sitearch/libc*
rm -rf %{buildroot}%_includedir/qmf
# NOTE: The following line fails on 64-bit as the artifacts are in
# /usr/lib/python2.6/site-packages/ not /usr/lib64/python2.6/site-packages/
# so we do the ugly thing and delete from both places until we can
# work this out!
rm -rf %{buildroot}%{python_sitelib}/qmfgen
rm -f %{buildroot}%_bindir/qmf-gen
rm -f %{buildroot}%_libdir/libqmf*
rm -f %{buildroot}%_libdir/librdmawrap.so
rm -f %{buildroot}%_libdir/pkgconfig/qmf2.pc

# These bits will be build if perl-devel package is installed
rm -fr %{buildroot}%_libdir/perl5

install -d -m0755 %{buildroot}%{_localstatedir}/lib/qpidd
install -m0600 %{_sourcedir}/qpidd.sasldb %{buildroot}%{_localstatedir}/lib/qpidd
install -d -m0755 %{buildroot}%_libdir/qpidd
install -d -m0755 %{buildroot}/var/run/qpidd

# enable auth by default
echo "auth=yes" >> %{buildroot}/etc/qpid/qpidd.conf

rm -f  %{buildroot}%_mandir/man1/*
install -d -m0755 %{buildroot}%_mandir/man1
install -p -m0644 %{SOURCE3} %{buildroot}%_mandir/man1

# ===

%clean
rm -rf %{buildroot}

# ===

%check
# All tests currently disabled, using 'make check' takes too long.
# TODO: Find a small smoke test that runs quickly, perhaps a special make target?

# ===

%post
/sbin/ldconfig

# ===

%postun
/sbin/ldconfig

# ===

%changelog
* Thu Mar  3 2016 Mike Cressman <mcressma@redhat.com> - 0.30-11
- Resolved: 1246152
- QPID-6548,6549 - init script updates
- Built with qpid-proton-0.9-13

* Tue Jun  9 2015 Irina Boverman <iboverma@redhat.com> - 0.30-10
- Resolved: 1223795

* Wed Jun  3 2015 Irina Boverman <iboverma@redhat.com> - 0.30-9
- Rebuilt against qpid-proton-0.9-4
- Added QPID-6563 patch

* Tue Mar 31 2015 Irina Boverman <iboverma@redhat.com> - 0.30-8
- Resolved: 1179341, 1202376
- Rebuilt against qpid-proton-0.9-2

* Tue Mar 10 2015 Irina Boverman <iboverma@redhat.com> - 0.30-7
- Resolved: 1187636, 1193170, 1194777

* Tue Feb  3 2015 Irina Boverman <iboverma@redhat.com> - 0.30-6
- Resolved: 985870, 1179609, 1184124, 1186693 	

* Tue Jan  6 2015 Irina Boverman <iboverma@redhat.com> - 0.30-5
- Resolved: 985870, 1095849, 1145386, 1160232, 1163650 

* Fri Nov  7 2014 Irina Boverman <iboverma@redhat.com> - 0.30-4
- Resolved: 995496, 1089652, 1147977, 1158903, 1158906, 1158910, 
  1160154

* Wed Oct 29 2014 Irina Boverman <iboverma@redhat.com> - 0.30-3
- Added changes needed to build Windows client

* Thu Oct  2 2014 Irina Boverman <iboverma@redhat.com> - 0.30-2
- Added option to build linearstore and disabled legacystore build

* Tue Sep 30 2014 Irina Boverman <iboverma@redhat.com> - 0.30-1
- Initial build using qpid-cpp-0.30.tar.gz

* Fri Sep 12 2014 Irina Boverman <iboverma@redhat.com> - 0.22-49
- Resolved: 1139351

* Fri Aug 29 2014 Irina Boverman <iboverma@redhat.com> - 0.22-48
- Resolved: 1128051, 1132350, 1132427, 1133948, 1129997 (partial)

* Fri Aug 22 2014 Irina Boverman <iboverma@redhat.com> - 0.22-47
- Resolved: 1051555, 1117708, 1128653, 1129277, 1130467, 
  1129997 (partial)

* Fri Aug  8 2014 Irina Boverman <iboverma@redhat.com> - 0.22-46
- Resolved: 1121660, 1122928, 1122966, 1126952, 1127089

* Fri Aug  1 2014 Irina Boverman <iboverma@redhat.com> - 0.22-45
- Resolved: 1117823, 1121623, 1124906

* Tue Jul 22 2014 Irina Boverman <iboverma@redhat.com> - 0.22-44
- Resolved: 1011221, 1086638, 1117745 

* Mon Jul 14 2014 Irina Boverman <iboverma@redhat.com> - 0.22-43
- Resolved: 1090376, 1090395

* Fri Jun  6 2014 Irina Boverman <iboverma@redhat.com> - 0.22-42
- Resolved: 1098118, 1105221

* Fri May 23 2014 Irina Boverman <iboverma@redhat.com> - 0.22-41
- Resolved: 1091639, 1098118, 1100402, 1100442

* Fri May 16 2014 Irina Boverman <iboverma@redhat.com> - 0.22-40
- Resolved: 1076392, 1078142, 1082487, 1090368, 1091558, 1091638,
  1091639, 1097559, 1097848 

* Fri Apr 25 2014 Irina Boverman <iboverma@redhat.com> - 0.22-38
- Resolved: 1061736, 1066180, 1076545, 1085053, 1086638, 1087827,
  1075223, 1077384 	

* Fri Apr  4 2014 Irina Boverman <iboverma@redhat.com> - 0.22-37
- Resolved: 1052046, 1071222, 1072469, 1075223, 1077384

* Fri Mar  7 2014 Irina Boverman <iboverma@redhat.com> - 0.22-36
- Resolved: 1015291, 1039550, 1044001, 1063700, 1064181, 1069743

* Fri Feb  7 2014 Irina Boverman <iboverma@redhat.com> - 0.22-35
- Resolved: 889552, 1004411, 1024528, 1035843, 1039522, 1039525, 
  1039550, 1045092, 1049359, 1049376, 1049498, 1049507, 1049803, 
  1050867, 1050877, 1053701, 1053749, 1053761, 1054448, 1055583, 
  1056157, 1056635, 1059785, 1060202, 1061754 	

* Wed Jan 15 2014 Irina Boverman <iboverma@redhat.com> - 0.22-33
- Changed qpid-cpp-store to conflict with qpid-cpp-linearstore
- Resolved: 1008565, 1038047, 1039949, 1048198, 1049258, 1050937,
  1051097, 1051441, 1051453, 1051555, 1051924, 1052445, 1052518,
  1052727, 1052775

* Mon Jan  6 2014 Irina Boverman <iboverma@redhat.com> - 0.22-31
- Resolved Windows build issue

* Fri Jan  3 2014 Irina Boverman <iboverma@redhat.com> - 0.22-30
- Resolved: 859119, 927444, 970668, 975444, 1001772, 1006022, 1009454, 
  1010390, 1024528, 1024832, 1033628, 1035802, 1036071, 1036134, 1038789, 
  1039626, 1039630, 1040614, 1040628, 1043035, 1045091, 1045407

* Tue Nov 26 2013 Irina Boverman <iboverma@redhat.com> - 0.22-29
- Changed installation directives

* Fri Nov 22 2013 Irina Boverman <iboverma@redhat.com> - 0.22-29
- Resolved Windows build problem

* Fri Nov 22 2013 Irina Boverman <iboverma@redhat.com> - 0.22-27
- Resolved: 709325, 1007819, 1026483, 1030219, 1031617, 1032582 	

* Fri Nov 15 2013 Irina Boverman <iboverma@redhat.com> - 0.22-26
- Added -DCMAKE_MODULE_LINKER_FLAGS=-Wl,-z,relro to cmake
- Resolved: 1019189, 1021941, 1027385, 1027391, 1029418, 1029426, 
  1029428, 1029432, 1029437, 1029440, 1029442, 1029446

* Wed Nov  6 2013 Irina Boverman <iboverma@redhat.com> - 0.22-25
- Removed qpid-cpp-tar package
- Resolved: 996249, 1010584, 1019189, 1019432, 1023641, 1024385, 
  1024396, 1024944, 1024957, 1024972, 1025381, 1025693, 1025771,
  1025828, 1026327, 1026354

* Fri Oct 25 2013 Irina Boverman <iboverma@redhat.com> - 0.22-23
- Resolved: 1023083, 1023418

* Thu Oct 24 2013 Irina Boverman <iboverma@redhat.com> - 0.22-22
- Resolved: 1018749, 1021569, 1021609, 1021616

* Mon Oct 21 2013 Irina Boverman <iboverma@redhat.com> - 0.22-21
- Resolved: 927444

* Fri Oct 18 2013 Irina Boverman <iboverma@redhat.com> - 0.22-20
- Resolved: 990972, 1002954, 1018746, 1018749, 1018765, 1018845, 1019150, 1019180, 1019181, 1019236, 1019404, 1019645 

* Fri Oct 11 2013 Irina Boverman <iboverma@redhat.com> - 0.22-19
- Resolved: 995554, 1004838, 1005736, 1012852, 1014076, 1014163, 1017113 
- Removed amqpc.so library

* Fri Sep 27 2013 Irina Boverman <iboverma@redhat.com> - 0.22-18
- Added changes to support bz995554

* Thu Sep 25 2013 Irina Boverman <iboverma@redhat.com> - 0.22-17
- Resolved bz(s): 915821, 955688, 955688, 1009454, 1009467, 1009525, 1009816, 1010390, 1010393, 1010395, 1010955, 1011519, 1011631, 1011902

* Fri Sep 20 2013 Irina Boverman <iboverma@redhat.com> - 0.22-16
- Resolved bz(s): 969039, 974061, 987961, 995039, 1009422

* Fri Sep 13 2013 Irina Boverman <iboverma@redhat.com> - 0.22-14
- Resolved bz(s): 949739, 971894, 987961, 995039, 1003674, 1004002, 1004474, 1006962, 1006976, 1006980
- Removed .../qpid/amqp_0_10, .../qpid/log, .../qpid/management from client-devel package (removed from source)

* Tue Sep  3 2013 Irina Boverman <iboverma@redhat.com> - 0.22-13
- Changed qpid-proton... >= 0.5

* Fri Aug 30 2013 Irina Boverman <iboverma@redhat.com> - 0.22-12
- Resolved bz(s): 967734, 981636, 997919, 999505, 1000587, 1001772

* Thu Aug 15 2013 Irina Boverman <iboverma@redhat.com> - 0.22-11
- Resolves bz: 966944, 996057, 996075, 996078, 996092, 996094, 996100, 996573 

* Fri Aug  9 2013 Irina Boverman <iboverma@redhat.com> - 0.22-10
- Resolved bz: 453533, 691411, 874516, 977290 (windows build), 990972

* Thu Aug  1 2013 Irina Boverman <iboverma@redhat.com> - 0.22-9
- Resolved bz: 987961 (windows build)

* Thu Jul 25 2013 Irina Boverman <iboverma@redhat.com> - 0.22-8
- Resolved bz(s): 894375, 985919, 987535 

* Wed Jul 10 2013 Irina Boverman <iboverma@redhat.com> - 0.22-7
- Changed /etc/qpidd.conf to /etc/qpid/qpidd.conf
- Added doxygen/make docs-user-api and removed Source2
- Resolved bz(s): 768114, 888501, 916953, 953662, 975046, 977820, 977891, 979385, 981638, 981640, 981642, 983514, 983517 

* Fri Jun 28 2013 Irina Boverman <iboverma@redhat.com> - 0.22-6
- Resolved bz(s): 976398, 978379, 978468, 978902, 975949, 959447, 970748 and 975937

* Fri Jun 21 2013 Irina Boverman <iboverma@redhat.com> - 0.22-5
- Resolved bz(s): 975422, 975423, 975430, 975434, 975444, 975446, 975451, 975460, 975463 and 975088 

* Wed Jun 19 2013 Irina Boverman <iboverma@redhat.com> - 0.22-4
- Added qpid-send and qpid-receive to (a) be part of the -devel package and (b) get installed to /usr/bin.

* Thu Jun 13 2013 Irina Boverman <iboverma@redhat.com> - 0.22-4
- Updated to include qpid-cpp-doxygen-0.22.html.tar.gz

* Tue Jun 11 2013 Irina Boverman <iboverma@redhat.com> - 0.22-3
- Updated source tarball and added fixes for these BZ(s):
  928951, 808105, 953662, 949014, 865689, 733758, 906814,
  739863, 862899, 703891, 796765, 889552, 797092, 453533, 
  970748, 901590, 902312, 955578, 958444, 970748, 825075, 
  588504, 955674, 782070, 959447, 961014, 959452, 928935, 
  963245, 963367, 691411, 970748, 970748, 957871, 964224, 
  963243, 963244, 964228, 969049, 962311
- Added fixes for qpid-sdk:
  715284, 846671, 905661 

* Thu May 30 2013 Irina Boverman <iboverma@redhat.com> - 0.22-2
- Added qpid-cpp-tar package to generate a tarball for Windows SDK build

* Mon May  6 2013 Irina Boverman <iboverma@redhat.com> - 0.22-2
- Resolved problem with shared library versions

* Fri Apr 19 2013 Irina Boverman <iboverma@redhat.com> - 0.22-1
- Made changes for 0.22/cmake based build

* Thu Jan 24 2013 Mike Cressman <mcressman@redhat.com> - 0.18-14
- consolidated the store patch files, now using the new 0.18 store branch
  (no code changes)
- BZs: 835119,884036,887044,896451
- HA BZs: 883548,886262,886656

* Wed Dec 12 2012 Mike Cressman <mcressman@redhat.com> - 0.18-13
- BZs: 846465
- new HA regression BZs: 861162,882149,882373,883548,884036,885658

* Tue Dec 4 2012 Mike Cressman <mcressman@redhat.com> - 0.18-12
- BZs: 872392,872946,877553,878638
- added another store patch(5) with updated generated qmf files

* Tue Nov 27 2012 Mike Cressman <mcressman@redhat.com> - 0.18-11
- HA BZs: 876688,876720,877081

* Tue Nov 20 2012 Mike Cressman <mcressman@redhat.com> - 0.18-10
- BZs: 875660, 876664
- HA BZs: 860701, 874192, 874118,874298
- remove faulty fix for 871100
- add new /etc/qpid/qpidd.acl
- qmf build cleanup
- add back deprecated fromString() that we must carry on MRG 2.x
  for compatibility

* Mon Nov 12 2012 Mike Cressman <mcressman@redhat.com> - 0.18-9
- HA BZs: 872696,873883,874118,874298

* Fri Nov 9 2012 Mike Cressman <mcressman@redhat.com> - 0.18-8
- BZs: 872172, 873465
- Fixed the windows build for 0.18

* Tue Nov 6 2012 Mike Cressman <mcressman@redhat.com> - 0.18-7
- BZs: 868881,873347
- HA BZs: 860701 - restore old qmf-1 interfaces, keeping new ones also
- store cleanup related to qmf changes

* Thu Nov 1 2012 Mike Cressman <mcressman@redhat.com> - 0.18-6
- BZs: 868951,871774
- HA BZs: 869002
- revert PACKAGE_NAME naming in generated qmf code

* Wed Oct 31 2012 Mike Cressman <mcressman@redhat.com> - 0.18-4
- BZs: 802656,804752,836141,861838,866677,868403,870058
- HA BZs: 860701,865524,867030,868360,868364,869420,871100
- updated store for new management interfaces

* Fri Oct 12 2012 Mike Cressman <mcressman@redhat.com> - 0.18-2
- BZs merged from 2.2: 609685,683711,689408,799269,831365
- New BZs: 861165,863349, HA BZs: 859170,860691,860704,865524,865846
- add perl/swig support files to client-devel
- updated man page

* Wed Oct 3 2012 Mike Cressman <mcressman@redhat.com> - 0.18-1
- rebase to 0.18
- update library revs

* Thu Sep 6 2012 Mike Cressman <mcressman@redhat.com> - 0.14-22
- BZs: 609685, 849654, 854004 

* Mon Aug 13 2012 Mike Cressman <mcressman@redhat.com> - 0.14-21
- BZs: 831365, 840982, 844618

* Wed Aug 1 2012 Mike Cressman <mcressman@redhat.com> - 0.14-20
- BZs: 683711, 689408, 825078, 834608, 841196, 841488

* Mon Jul 23 2012 Mike Cressman <mcressman@redhat.com> - 0.14-19
- BZs: 609685, 683711, 693444, 707682, 729311, 801465, 808090,
       809357, 811481, 817283, 826989, 831365, 835628

* Fri Jul 13 2012 Irina Boverman <iboverma@redhat.com> - 0.14-18
- BZs: 609685, 729311, 808090, 809357, 817283

* Tue Apr 24 2012 Ted Ross <tross@redhat.com> - 0.14-16
- Related: rhbz#703563
- Related: rhbz#771961
- Related: rhbz#785919
- Related: rhbz#788901
- Related: rhbz#799269
- Related: rhbz#802807

* Wed Mar 21 2012 Justin Ross <jross@redhat.com> - 0.14-15
- Related: rhbz#765803
- Rebase to 0.14
- BZs: 730017, 759114, 760636, 786875, 791249, 795399, 797426, 798236,
  800028, 801310

* Tue Oct 18 2011 Ted Ross <tross@redhat.com> - 0.12-6
- Related: rhbz#740912
- Removed dependencies on xqilla and xerces-c for non-Intel architectures

* Mon Oct 3 2011 Justin Ross <jross@redhat.com> - 0.12-5
- Related: rhbz#742040
- Remove the indirection for subpackage renaming; we no longer need it
- Adapt spec file to use upstream qpid source tarball as-is
- Rebase qpid and store source to 0.12
- Restore changes for new architectures

* Wed Sep 14 2011 Ted Ross<tross@redhat.com> - 0.12-3
- BZ 681680 - QMF agents wake up several times a second
- BZ 699499 - [RFE] qmfv2 must provide mainloop integration

* Mon Jul 25 2011 Ted Ross<tross@redhat.com> - 0.12-1
- BZ 663461 - Enable new architectures
- BZ 706949 - Rebase to Qpid 0.12

* Tue Jun 8 2011 Kim van der Riet<kim.vdriet@redhat.com> - 0.10-4
- Related rhbz#711834
- MRG 2.0 GA build for RHEL 6.1.z, equates to 0.10-8.el5 build
- The mrg-2.0.x patch file was updated to include:
  - BZ 707023: RPMdiff failure (multilib regressions) in qpid-qmf
  - BZ 709343: Packaging problem in qpid-qmf-devel (qmf-gen templates)
  - BZ 709862: dash-7 source RPM does not build
  - BZ 671369: RDMA client can segfault when no SASL mechanism specified
- Catch-up build corresponding to RHEL-5 builds 0.10-4 -5 -6 and -7:
- RHEL-5 0.10-4:
  - 2.0 RC build 1
  - BZs: 690261,693407,695263,695716,696637,696655,696698
- RHEL-5 0.10-5:
  - Intermediate build to address rpmdiff/multilib problems
  - BZs: 689907
  - Now sourcing the doxygen-generated HTML from distcvs
- RHEL-5 0.10-6:
  - 2.0 RC build 2
  - BZs: 675921,681313,689907,698254,700822,701709,701777,701786,701804
- RHEL-5 0.10-7:
  - 2.0 RC build 3
  - BZs: 693895,698721

* Tue Apr 5 2011 Kim van der Riet<kim.vdriet@redhat.com> - 0.10-3
- Related: rhbz#675821

* Wed Mar 30 2011 Kim van der Riet<kim.vdriet@redhat.com> - 0.10-2
- Related: rhbz#675821
- Fix for missing uuid lib dependency
- QMF v2 generation bug fix

* Wed Mar 23 2011 Kim van der Riet<kim.vdriet@redhat.com> - 0.10-1
- Related: rhbz#675821 - Rebase to upstream 0.10 rev 1083082 (store rev
  remains 4446)
- Removing svn rev no. from the package names

* Wed Mar 9 2011 Kim van der Riet<kim.vdriet@redhat.com> - 0.9.1079953-1
- Related: rhbz#675821 - Redo latest build because of windows build error.

* Tue Mar 8 2011 Kim van der Riet<kim.vdriet@redhat.com> - 0.9.1078967-1
- Related: rhbz#675821 - First build of 0-10 branch, but because final
  numbering strategy is still undecided, the 0.9.x label persists for this
  build. QMF has been removed entirely and placed into its own package, as
  there were not only inconsistencies in the old packaging, but also name
  clashes.

* Fri Feb 23 2011 Kim van der Riet<kim.vdriet@redhat.com> - 0.9.1073306-1
- Related: rhbz#675821 - Rebase qpid-cpp to 0.10 for snapshot 3
  Note that the current qpid trunk is still in 0.9, but will branch onto
  the 0.10 release branch soon. This is a test build only.

* Fri Feb 7 2011 Kim van der Riet<kim.vdriet@redhat.com> - 0.7.946106-13
- Related: rhbz#659098 - Missing libqmf2.so.* in qmf package and
  libqmf2.so in qmf-devel package

* Fri Feb 4 2011 Kim van der Riet<kim.vdriet@redhat.com> - 0.7.946106-12
- Related: rhbz#659098 - QMFv2 API for C++
- Related: rhbz#617260 - qmf agent crashes broker when queue limits exceeded
- Related: rhbz#659100 - QMFv2 API for Python
- Related: rhbz#662826 - Support for federated brokers in QMF
  This build adds QMF v.2 to the previous MRG 1.3.2 RC2 build, and a
  new python-qmf2 subpackage (rpm).

* Fri Feb 4 2011 Kim van der Riet<kim.vdriet@redhat.com> - 0.7.946106-11
- Related: rhbz#631002 - Synchronize qpid-cpp build to MRG 1.3.
  This build synchronizes with RHEL-{4,5} qpid-cpp-mrg-0.7.946106-28 (MRG 1.3.2 RC2).
  Updated lib version numbers for RHEL 6.1.

* Fri Jan 14 2011 Kim van der Riet<kim.vdriet@redhat.com> - 0.7.946106-10
- Related: rhbz#631002 - Synchronize qpid-cpp build to MRG 1.3.
  This build synchronizes with RHEL-{4,5} qpid-cpp-mrg-0.7.946106-26.

* Mon Oct 4 2010 Kim van der Riet<kim.vdriet@redhat.com> - 0.7.946106-9
- Related: rhbz#631002 - Synchronize qpid-cpp build to MRG 1.3.
  This build synchronizes with RHEL-{4,5} qpid-cpp-mrg-0.7.946106-17.

* Thu Sep 16 2010 Kim van der Riet<kim.vdriet@redhat.com> - 0.7.946106-8
- Related: rhbz#631002 - Synchronize qpid-cpp build to MRG 1.3.
  This build synchronizes with RHEL-{4,5} qpid-cpp-mrg-0.7.946106-15.

* Tue Sep 14 2010 Kim van der Riet<kim.vdriet@redhat.com> - 0.7.946106-7
- Related: rhbz#631002 - Synchronize qpid-cpp build to MRG 1.3.
  This build synchronizes with RHEL-{4,5} qpid-cpp-mrg-0.7.946106-14.

* Tue Sep 7 2010 Kim van der Riet<kim.vdriet@redhat.com> - 0.7.946106-6
- Related: rhbz#631002 - Synchronize qpid-cpp build to MRG 1.3
  Updated to latest 1.3 patches.
  Removed MRG-core and MRG-non-core flags from spec file. Also removed the
  core_release global, no longer needed as the el6mrg dist tag has gone.

* Wed Jul 14 2010 Kim van der Riet<kim.vdriet@redhat.com> - 0.7.946106-5
- Related: rhbz#609298 - ruby QMF bindings can't query agents
  Fix in undelying c++ code for ruby QMF bindings.

* Wed Jul 14 2010 Kim van der Riet<kim.vdriet@redhat.com> - 0.7.946106-4
- Related: rhbz#612285, rhbz#612283
  Updated to MRG 1.3 beta 4

* Fri Jun 18 2010 Kim van der Riet<kim.vdriet@redhat.com> - 0.7.946106-3
- Related: rhbz#604173 - Fixed problems with libs and flags which were
  inconsistent.

* Thu Jun 17 2010 Kim van der Riet<kim.vdriet@redhat.com> - 0.7.946106-3
- Related: rhbz#604173 - Added patch set for MRG 1.3. Modified spec file
  to set the lib versions for each of the libs produced by the build
  independently of each other and pass that info as params to make.

* Wed Jun 16 2010 Kim van der Riet<kim.vdriet@redhat.com> - 0.7.946106-3
- Related: rhbz#602696 - removed post script 'semodule -r qpidd' and
           deps on semodule.
- Related: rhbz#587226 - removed qpidd.sasldb which is causing multilib
           conflict.

* Tue May 25 2010 Kim van der Riet<kim.vdriet@redhat.com> - 0.7.946106-2
- Related: rhbz#595710
- Added patch bz595710.patch as Patch0, fixes QMF API problem.

* Wed May 19 2010 Kim van der Riet<kim.vdriet@redhat.com> - 0.7.946106-1
- Related: rhbz#574881
- Rebase to qpid r.946106 / store r.3975
- New build process: building all packages for RHEL-6 in one build; relying
  on compose to split the rpms amongst core RHEL-6 and MRG channels.
- Removed the qpidd.sasldb file; this caused a multi-lib problem, and is used for
  testing only (BZ587226).
- Added new client lib libqpidmessaging.so.
- Limited examples to the messaging dir only.

* Mon Apr 19 2010 Kim van der Riet<kim.vdriet@redhat.com> - 0.7.935473-1
- Related: rhbz#574416
  Updated SELinux handling - remove qpidd.pp
  Rebase sources on svn r.935473/r.3913 (initial build for MRG 1.3)

* Tue Mar 2 2010 Kim van der Riet<kim.vdriet@redhat.com> - 0.6.895736-5
- Related: rhbz#569937
  Adds missing post actions to set up openais/corosync.
  Fixed up numerous inconsistencies and small discreppanecies in spec file.
  More efficient build which limits the packages built when building only
  core rpms.

* Wed Feb 3 2010 Kim van der Riet<kim.vdriet@redhat.com> - 0.6.895736-5
- Related: rhbz#554415
  Changed name of fedora_lib_patch flag to simply fedora
  Added rhel_5 flag, and put in switches for rhel-5 libs
  Added new boost libs for RHEL-6/Fedora

* Tue Jan 26 2010 Kim van der Riet <kim.vdriet@redhat.com> - 0.6.895736-4
- Related: rhbz#554415
  Added a package name varialbe; removed make dist in store build. Fixed
  some rpmlint warnings.

* Thu Jan 14 2010 Kim van der Riet <kim.vdriet@redhat.com> - 0.6.895736-3
- Related: rhbz#554415
  Moved the -devel and -devel-docs into MRG_core for initial RHEL-6
  release.

* Thu Jan 14 2010 Kim van der Riet <kim.vdriet@redhat.com> - 0.6.895736-3
- Related: rhbz#554415
  Parametized lib revision numbers and Fedora patches, updated files that
  need to be removed.

* Wed Jan 13 2010 Kim van der Riet <kim.vdriet@redhat.com> - 0.6.895736-3
- Related: rhbz#554415
  removed a remaining patch0 tag

* Wed Jan 13 2010 Kim van der Riet <kim.vdriet@redhat.com> - 0.6.895736-3
- Related: rhbz#554415
  Removed so_number.patch (used in Fedora, but not needed for RHEL)

* Wed Jan 13 2010 Kim van der Riet <kim.vdriet@redhat.com> - 0.6.895736-2
- Related: rhbz#554415
  Changed architecture flags from BuildArchitectures: to ExclusiveArch:

* Wed Jan 13 2010 Kim van der Riet <kim.vdriet@redhat.com> - 0.6.895736-1
- Related: rhbz#554415
  Limited builds to i686 and x86_64 archs.
  Rebased qpid to r.895736 (qpid 0.6 branch) and store to r.3795

* Tue Jan 12 2010 Kim van der Riet <kim.vdriet@redhat.com> - 0.5.819892-3
- qpid-cpp: Add qpid-cpp package to RHEL-6 (rhbz#554415)
  Related: rhbz#554415
  Copied from rawhide and split project into core and non-core parts:
  core:     The RHEL-6 core components distributed with the base OS
  non-core: The remaining MRG components that make up the subscription product.

* Tue Oct 27 2009 Nuno Santos <nsantos@redhat.com> - 0.5.819819-2
- Renaming of subpackages as per http://fedoraproject.org/wiki/Features/ImprovedQpidCppPackaging

* Tue Sep 29 2009 Nuno Santos <nsantos@redhat.com> - 0.5.819819-1
- Rebased to svn rev 819819 for F12 beta

* Thu Sep 24 2009 Nuno Santos <nsantos@redhat.com> - 0.5.818599-1
- Rebased to svn rev 818599
- rhm-cpp-server-store obsoletes rhm top-level package

* Fri Sep 19 2009 Nuno Santos <nsantos@redhat.com> - 0.5.817349
- Rebased to svn rev 817349

* Wed Jul 29 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 0.5.790661-3
- Update BuildRequires and Requires to use latest stable versions of
  corosync and clusterlib.
- Unbreak perftests define (and fix vim spec syntax coloring).

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.790661-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Jul  2 2009 Nuno Santos <nsantos@redhat.com> - 0.5.790661-1
- Rebased to svn rev 790661; .so lib numbers bumped

* Fri Jun 26 2009 Nuno Santos <nsantos@redhat.com> - 0.5.788782-1
- Rebased to svn rev 788782

* Mon Jun 22 2009 Nuno Santos <nsantos@redhat.com> - 0.5.787286-1
- Rebased to svn rev 787286

* Wed Jun 10 2009 Fabio M. Di Nitto <fdinitto@redhat.com> - 0.5.752600-8
- update BuildRequires to use corosynclib-devel in correct version.
- update BuildRequires to use clusterlib-devel instead of the obsoleted
  cmanlib-devel.
- drop Requires on cmanlib. This should come in automatically as part
  of the rpm build process.
- re-align package version to -8. -7 didn't have a changelog entry?
- add patch to port Cluster/Cpg to newest Cpg code.
- change patch tag to use patch0.

* Mon May  4 2009 Nuno Santos <nsantos@redhat.com> - 0.5.752600-5
- patch for SASL credentials refresh

* Wed Apr  1 2009 Michael Schwendt <mschwendt@fedoraproject.org> - 0.5.752600-5
- Fix unowned examples directory in -devel pkg.

* Mon Mar 16 2009 Nuno Santos <nsantos@localhost.localdomain> - 0.5.752600-4
- BZ483925 - split docs into a separate noarch subpackage

* Mon Mar 16 2009 Nuno Santos <nsantos@redhat.com> - 0.5.752600-3
- Disable auth by default; fix selinux requires

* Wed Mar 11 2009 Nuno Santos <nsantos@redhat.com> - 0.5.752600-1
- Rebased to svn rev 752600

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.738618-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.738618-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Jan 28 2009 Nuno Santos <nsantos@redhat.com> - 0.4.738618-2
- Rebased to svn rev 738618

* Tue Jan 20 2009 Nuno Santos <nsantos@redhat.com> - 0.4.734452-3
- BZ474614 and BZ474613 - qpidc/rhm unowned directories

* Thu Jan 15 2009 Nuno Santos <nsantos@redhat.com> - 0.4.734452-1
- Rebased to svn rev 734452

* Tue Dec 23 2008 Nuno Santos <nsantos@redhat.com> - 0.4.728142-1
- Rebased to svn rev 728142
- Re-enable cluster, now using corosync

* Tue Dec  2 2008 Nuno Santos <nsantos@redhat.com> - 0.3.722557-1
- Rebased to svn rev 722557
- Temporarily disabled cluster due to openais version incompatibility

* Wed Nov 26 2008 Nuno Santos <nsantos@redhat.com> - 0.3.720979-1
- Rebased to svn rev 720979

* Fri Nov 21 2008  Mick Goulish <mgoulish@redhat.com>
- updated to 719552

* Thu Nov 20 2008  Mick Goulish <mgoulish@redhat.com>
- updated to 719323
- For subpackage qpidd-cluster, added dependency to cman-devel.
- For subpackage qpidd-cluster, added dependency to qpidc.
- added BuildRequires cman-devel

* Fri Nov 14 2008 Justin Ross <jross@redhat.com> - 0.3.714072-1
- Update to svn rev 714072
- Enable building --with-cpg

* Wed Nov 12 2008 Justin Ross <jross@redhat.com> - 0.3.713378-1
- Update to svn rev 713378

* Fri Nov  7 2008 Justin Ross <jross@redhat.com> - 0.3.712127-1
- Update to svn rev 712127

* Thu Nov  6 2008 Nuno Santos <nsantos@redhat.com> - 0.3.711915-2
- Removed extraneous openais-devel dependency

* Thu Nov  6 2008 Justin Ross <jross@redhat.com> - 0.3.711915-1
- Update to svn rev 711915

* Tue Nov  4 2008 Nuno Santos <nsantos@redhat.com> - 0.3.709187-2
- Remove extraneous dependency

* Thu Oct 30 2008 Nuno Santos <nsantos@redhat.com> - 0.3.709187-1
- Rebsed to svn rev 709187

* Tue Oct 28 2008 Nuno Santos <nsantos@redhat.com> - 0.3.708576-1
- Rebased to svn rev 708576

* Mon Oct 27 2008 Nuno Santos <nsantos@redhat.com> - 0.3.708210-1
- Rebased to svn rev 708210; address make check libtool issue

* Fri Oct 24 2008 Justin Ross <jross@redhat.com> - 0.3.707724-1
- Update to revision 707724

* Thu Oct 23 2008 Justin Ross <jross@redhat.com> - 0.3.707468-1
- Don't use silly idenity defines
- Add new ssl and rdma subpackages
- Move cluster and xml plugins into their own subpackages
- Reflect new naming of plugins

* Wed Aug 21 2008 Justin Ross <jross@redhat.com> - 0.2.687156-1
- Update to source revision 687156 of the qpid.0-10 branch

* Wed Aug 14 2008 Justin Ross <jross@redhat.com> - 0.2.685273-1
- Update to source revision 685273 of the qpid.0-10 branch

* Wed Aug  6 2008 Justin Ross <jross@redhat.com> - 0.2.683301-1
- Update to source revision 683301 of the qpid.0-10 branch

* Thu Jul 15 2008 Justin Ross <jross@redhat.com> - 0.2.676581-1
- Update to source revision 676581 of the qpid.0-10 branch
- Work around home dir creation problem
- Use a license string that rpmlint likes

* Thu Jul 10 2008 Nuno Santos <nsantos@redhat.com> - 0.2.667603-3
- BZ453818: added additional tests to -perftest

* Thu Jun 13 2008 Justin Ross <jross@redhat.com> - 0.2.667603-1
- Update to source revision 667603

* Thu Jun 12 2008 Justin Ross <jross@redhat.com> - 0.2.667253-1
- Update to source revision 667253

* Thu Jun 12 2008 Nuno Santos <nsantos@redhat.com> - 0.2.666138-5
- add missing doc files

* Wed Jun 11 2008 Justin Ross <jross@redhat.com> - 0.2.666138-3
- Added directories for modules and pid files to install script

* Wed May 28 2008 David Sommerseth <dsommers@redhat.com> - 0.2.663761-1
- Added perftest utilities

* Thu May 22 2008 Nuno Santos <nsantos@redhat.com> - 0.2.656926-4
- Additional build flags for i686

* Tue May 20 2008 Nuno Santos <nsantos@redhat.com> - 0.2.656926-3
- BZ 432872: remove examples, which are being packaged separately

* Tue May 20 2008 Justin Ross <jross@redhat.com> -0.2.656926-2
- Drop build requirements for graphviz and help2man

* Wed May 14 2008 Nuno Santos <nsantos@redhat.com> - 0.2-34
- Bumped for Beta 4 release

* Fri May  9 2008 Matthew Farrellee <mfarrellee@redhat> - 0.2-33
- Moved qpidd.conf from qpidc package to qpidd package
- Added BuildRequires xqilla-devel and xerces-c-devel to qpidd for XML Exchange
- Added BuildRequires openais-devel to qpidd for CPG
- Added missing Requires xqilla-devel to qpidd-devel

* Thu May  8 2008 Matthew Farrellee <mfarrellee@redhat> - 0.2-32
- Added sasl2 config file for qpidd
- Added cyrus-sasl dependencies

* Wed May  7 2008 Matthew Farrellee <mfarrellee@redhat> - 0.2-31
- Added python dependency, needed by managementgen

* Wed May  7 2008 Matthew Farrellee <mfarrellee@redhat> - 0.2-30
- Added management-types.xml to qpidc-devel package

* Tue May  6 2008 Matthew Farrellee <mfarrellee@redhat> - 0.2-29
- Added managementgen to the qpidc-devel package

* Mon Apr 14 2008 Nuno Santos <nsantos@redhat.com> - 0.2-28
 - Fix home dir permissions
 - Bumped for Fedora 9

* Mon Mar 31 2008 Nuno Santos <nsantos@redhat.com> - 0.2-25
- Create user qpidd, start qpidd service as qpidd

* Mon Feb 18 2008 Rafael Schloming <rafaels@redhat.com> - 0.2-24
- Bug fix for TCK issue in Beta 3

* Thu Feb 14 2008 Rafael Schloming <rafaels@redhat.com> - 0.2-23
- Bumped to pull in fixes for Beta 3

* Tue Feb 12 2008 Alan Conway <aconway@redhat.com> - 0.2-22
- Added -g to compile flags for debug symbols.

* Tue Feb 12 2008 Alan Conway <aconway@redhat.com> - 0.2-21
- Create /var/lib/qpidd correctly.

* Mon Feb 11 2008 Rafael Schloming <rafaels@redhat.com> - 0.2-20
- bumped for Beta 3

* Mon Jan 21 2008 Gordon Sim <gsim@redhat.com> - 0.2-18
- bump up rev for recent changes to plugin modules & mgmt

* Thu Jan 03 2008 Nuno Santos <nsantos@redhat.com> - 0.2-17
- add missing header file SessionManager.h

* Thu Jan 03 2008 Nuno Santos <nsantos@redhat.com> - 0.2-16
- limit builds to i386 and x86_64 archs

* Thu Jan 03 2008 Nuno Santos <nsantos@redhat.com> - 0.2-15
- add ruby as a build dependency

* Tue Dec 18 2007 Nuno Santos <nsantos@redhat.com> - 0.2-14
- include fixes from Gordon Sim (fragmentation, lazy-loading, staging) 
  and Alan Conway (exception handling in the client).

* Thu Dec 6 2007 Alan Conway <aconway@redhat.com> - 0.2-13
- installcheck target to build examples in installation.

* Thu Nov 8 2007 Alan Conway <aconway@redhat.com> - 0.2-10
- added examples to RPM package.

* Thu Oct 9 2007 Alan Conway <aconway@redhat.com> - 0.2-9
- added config(noreplace) for qpidd.conf

* Thu Oct 4 2007 Alan Conway <aconway@redhat.com> - 0.2-8
- Added qpidd.conf configuration file.
- Updated man page to detail configuration options.

* Thu Sep 20 2007 Alan Conway <aconway@redhat.com> - 0.2-7
- Removed apr dependency.

* Wed Aug 1 2007 Alan Conway <aconway@redhat.com> - 0.2-6
- added --disable-cluster flag

* Tue Apr 17 2007 Alan Conway <aconway@redhat.com> - 0.2-5
- Add missing Requires: e2fsprogs-devel for qpidc-devel.

* Tue Apr 17 2007 Alan Conway <aconway@redhat.com> - 0.2-4
- longer broker_start timeout to avoid failures in plague builds.

* Tue Apr 17 2007 Alan Conway <aconway@redhat.com> - 0.2-3
- Add missing Requires: apr in qpidc.

* Mon Apr 16 2007 Alan Conway <aconway@redhat.com> - 0.2-2
- Bugfix for memory errors on x86_64.

* Thu Apr 12 2007 Alan Conway <aconway@redhat.com> - 0.2-1
- Bumped version number for rhm dependencies.

* Wed Apr 11 2007 Alan Conway <aconway@redhat.com> - 0.1-5
- Add qpidd-devel sub-package.

* Mon Feb 19 2007 Jim Meyering <meyering@redhat.com> - 0.1-4
- Address http://bugzilla.redhat.com/220630:
- Remove redundant "cppunit" build-requires.
- Add --disable-static.

* Thu Jan 25 2007 Alan Conway <aconway@redhat.com> - 0.1-3
- Applied Jim Meyerings fixes from http://mail-archives.apache.org/mod_mbox/incubator-qpid-dev/200701.mbox/<87hcugzmyp.fsf@rho.meyering.net>

* Mon Dec 22 2006 Alan Conway <aconway@redhat.com> - 0.1-1
- Fixed all rpmlint complaints (with help from David Lutterkort)
- Added qpidd --daemon behaviour, fix init.rc scripts

* Fri Dec  8 2006 David Lutterkort <dlutter@redhat.com> - 0.1-1
- Initial version based on Jim Meyering's sketch and discussions with Alan
  Conway
